@@ -27,7 +27,7 @@ use vars qw(%notfound %strip %servers %exceed);
     AM  whois.ripe.net
     AS  whois.gdns.net
     AT  whois.nic.at
-    AU  box2.aunic.net
+    AU  whois.ausregistry.net.au
     AZ  whois.ripe.net
     BA  whois.ripe.net
     BE  whois.dns.be
@@ -208,10 +208,6 @@ use vars qw(%notfound %strip %servers %exceed);
     'whois.dns.be' => '^Status:      FREE',
 );
 
-%exceed = (
-    'whois.ripn.net' => 'excessive querying of the WHOIS database',
-);
-
 %strip = (
     'whois.crsnic.net' => [
 	'^TERMS OF USE:',
@@ -360,6 +356,7 @@ use vars qw(%notfound %strip %servers %exceed);
     ],
     'whois.ripn.net' => [
 	'^%',
+	'Last updated on ',
     ],
     'whois.nic.uk' => [
 	'^The .* Registration Host contains information',
@@ -539,7 +536,28 @@ use vars qw(%notfound %strip %servers %exceed);
 	'^directNIC makes this information',
 	'^its accuracy\.',
     ],
+    'whois.alldomains.com' => [
+	'^MarkMonitor.com - ',
+	'^------------------',
+	'^For Global Domain ',
+	'^and Enterprise DNS,',
+	'^------------------',
+	'^The Data in MarkMon',
+	'^for information pur',
+	'^about or related to',
+	'^does not guarantee ',
+	'^that you will use t',
+	'^circumstances will ',
+	'^support the transmi',
+	'^solicitations via e',
+	'^electronic processe',
+	'^MarkMonitor.com res',
+	'^By submitting this ',
+    ],
 );
 
+%exceed = (
+    'whois.ripn.net' => 'excessive querying of the WHOIS database',
+);
 
 1;
